//@ts-check
"use strict";

/**
@typedef Boat
@type {{
  pos: PIXI.Point;
  pixiRoot: PIXI.Container;
  sprite: PIXI.AnimatedSprite;
  spritesheet: Spritesheet;
}}
*/

/**
 * @param {World} world 
 * @param {{ x: Number; y: Number;}} pos 
 */
function createBoat(world, pos) {
  const pixiRoot = new PIXI.Container();
  pixiRoot.scale.set(inverseTileSize);
  pixiRoot.position.set(pos.x, pos.y);
  world.pixiLayers["ground"].entitiesContainer.addChild(pixiRoot);
  pixiRoot.position.set(pos.x, pos.y);

  const spritesheet = getSpritesheet("inGame/boat/boat");
  const sprite = new PIXI.AnimatedSprite(spritesheet.animations["broken"], false);
  sprite.anchor.copyFrom(spritesheet.anchor);
  sprite.play();
  pixiRoot.addChild(sprite);

  const boat = world.boat = {
    pos: new PIXI.Point(pos.x, pos.y),
    pixiRoot,
    sprite,
    spritesheet
  };

  return boat;
}

function updateBoat(dt) {
  //@ts-ignore
  if (inGame.activeWorld.boat != null) inGame.activeWorld.boat.sprite.update(app.ticker.deltaTime);
}

function makeBoatRepaired() {
  const { boat } = inGame.worlds["overworld"];

  setAnimation(boat.sprite, boat.spritesheet.animations["repaired"]);
}